.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.py_source_parser
===============================

.. automodule:: sphinx_gallery.py_source_parser

   
   

   Functions
   ---------

   

   .. autofunction:: extract_file_config

   .. include:: backreferences/sphinx_gallery.py_source_parser.extract_file_config.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: parse_source_file

   .. include:: backreferences/sphinx_gallery.py_source_parser.parse_source_file.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: remove_config_comments

   .. include:: backreferences/sphinx_gallery.py_source_parser.remove_config_comments.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: split_code_and_text_blocks

   .. include:: backreferences/sphinx_gallery.py_source_parser.split_code_and_text_blocks.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>
   
   

   
   
   

   
   
   